pub struct SharingConfig {
pub bump: u8,
pub version: u8,
pub status: ConfigStatus,
pub mint: Pubkey,
pub admin: Pubkey,
pub admin_revoked: bool,
pub shareholders: Vec<Shareholder>,
}Fields
bump: u8version: u8status: ConfigStatusmint: Pubkeyadmin: Pubkeyadmin_revoked: boolTrait Implementations
Sourceimpl AccountDeserialize for SharingConfig
impl AccountDeserialize for SharingConfig
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for SharingConfig
impl AccountSerialize for SharingConfig
Sourceimpl BorshDeserialize for SharingConfig
impl BorshDeserialize for SharingConfig
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SharingConfigwhere
u8: BorshSerialize,
ConfigStatus: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
Vec<Shareholder>: BorshSerialize,
impl BorshSerialize for SharingConfigwhere
u8: BorshSerialize,
ConfigStatus: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
Vec<Shareholder>: BorshSerialize,
Sourceimpl Clone for SharingConfig
impl Clone for SharingConfig
Sourcefn clone(&self) -> SharingConfig
fn clone(&self) -> SharingConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SharingConfig
impl Debug for SharingConfig
Sourceimpl Discriminator for SharingConfig
impl Discriminator for SharingConfig
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more