pub struct AddQuoteMint {
pub global: Pubkey,
pub authority: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for AddQuoteMint.
Fields
global: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddQuoteMintwhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddQuoteMintwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddQuoteMint
impl ToAccountMetas for AddQuoteMint
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddQuoteMint
impl RefUnwindSafe for AddQuoteMint
impl Send for AddQuoteMint
impl Sync for AddQuoteMint
impl Unpin for AddQuoteMint
impl UnsafeUnpin for AddQuoteMint
impl UnwindSafe for AddQuoteMint