pub struct AdminSetCreator {
pub admin_set_creator_authority: Pubkey,
pub global: Pubkey,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for AdminSetCreator.
Fields
global: Pubkeymint: Pubkeybonding_curve: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AdminSetCreatorwhere
Pubkey: BorshSerialize,
impl BorshSerialize for AdminSetCreatorwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AdminSetCreator
impl ToAccountMetas for AdminSetCreator
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AdminSetCreator
impl RefUnwindSafe for AdminSetCreator
impl Send for AdminSetCreator
impl Sync for AdminSetCreator
impl Unpin for AdminSetCreator
impl UnsafeUnpin for AdminSetCreator
impl UnwindSafe for AdminSetCreator