pub struct DistributeCreatorFees {
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub sharing_config: Pubkey,
pub creator_vault: Pubkey,
pub system_program: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for DistributeCreatorFees.
Fields
mint: Pubkeybonding_curve: Pubkeysharing_config: Pubkeycreator_vault: Pubkeysystem_program: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for DistributeCreatorFeeswhere
Pubkey: BorshSerialize,
impl BorshSerialize for DistributeCreatorFeeswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for DistributeCreatorFees
impl ToAccountMetas for DistributeCreatorFees
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for DistributeCreatorFees
impl RefUnwindSafe for DistributeCreatorFees
impl Send for DistributeCreatorFees
impl Sync for DistributeCreatorFees
impl Unpin for DistributeCreatorFees
impl UnsafeUnpin for DistributeCreatorFees
impl UnwindSafe for DistributeCreatorFees