pub struct ExtendAccount {
pub account: Pubkey,
pub user: Pubkey,
pub system_program: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for ExtendAccount.
Fields
account: Pubkeyuser: Pubkeysystem_program: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ExtendAccountwhere
Pubkey: BorshSerialize,
impl BorshSerialize for ExtendAccountwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ExtendAccount
impl ToAccountMetas for ExtendAccount
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ExtendAccount
impl RefUnwindSafe for ExtendAccount
impl Send for ExtendAccount
impl Sync for ExtendAccount
impl Unpin for ExtendAccount
impl UnsafeUnpin for ExtendAccount
impl UnwindSafe for ExtendAccount