pub struct GetMinimumDistributableFee {
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub sharing_config: Pubkey,
pub creator_vault: Pubkey,
}Expand description
Generated client accounts for GetMinimumDistributableFee.
Fields
mint: Pubkeybonding_curve: Pubkeysharing_config: Pubkeycreator_vault: PubkeyTrait Implementations
Sourceimpl BorshSerialize for GetMinimumDistributableFeewhere
Pubkey: BorshSerialize,
impl BorshSerialize for GetMinimumDistributableFeewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for GetMinimumDistributableFee
impl ToAccountMetas for GetMinimumDistributableFee
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for GetMinimumDistributableFee
impl RefUnwindSafe for GetMinimumDistributableFee
impl Send for GetMinimumDistributableFee
impl Sync for GetMinimumDistributableFee
impl Unpin for GetMinimumDistributableFee
impl UnsafeUnpin for GetMinimumDistributableFee
impl UnwindSafe for GetMinimumDistributableFee