pub struct Migrate {Show 25 fields
pub global: Pubkey,
pub withdraw_authority: Pubkey,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub associated_bonding_curve: Pubkey,
pub user: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
pub pump_amm: Pubkey,
pub pool: Pubkey,
pub pool_authority: Pubkey,
pub pool_authority_mint_account: Pubkey,
pub pool_authority_wsol_account: Pubkey,
pub amm_global_config: Pubkey,
pub wsol_mint: Pubkey,
pub lp_mint: Pubkey,
pub user_pool_token_account: Pubkey,
pub pool_base_token_account: Pubkey,
pub pool_quote_token_account: Pubkey,
pub token_2022_program: Pubkey,
pub associated_token_program: Pubkey,
pub pump_amm_event_authority: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for Migrate.
Fields
global: Pubkeymint: Pubkeybonding_curve: Pubkeyassociated_bonding_curve: Pubkeyuser: Pubkeysystem_program: Pubkeytoken_program: Pubkeypump_amm: Pubkeypool: Pubkeyamm_global_config: Pubkeywsol_mint: Pubkeylp_mint: Pubkeyuser_pool_token_account: Pubkeypool_base_token_account: Pubkeypool_quote_token_account: Pubkeytoken_2022_program: Pubkeyassociated_token_program: Pubkeyprogram: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Migratewhere
Pubkey: BorshSerialize,
impl BorshSerialize for Migratewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for Migrate
impl ToAccountMetas for Migrate
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Migrate
impl RefUnwindSafe for Migrate
impl Send for Migrate
impl Sync for Migrate
impl Unpin for Migrate
impl UnsafeUnpin for Migrate
impl UnwindSafe for Migrate