pub struct SetCreator {
pub set_creator_authority: Pubkey,
pub global: Pubkey,
pub mint: Pubkey,
pub metadata: Pubkey,
pub bonding_curve: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for SetCreator.
Fields
global: Pubkeymint: Pubkeymetadata: Pubkeybonding_curve: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetCreatorwhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetCreatorwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetCreator
impl ToAccountMetas for SetCreator
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetCreator
impl RefUnwindSafe for SetCreator
impl Send for SetCreator
impl Sync for SetCreator
impl Unpin for SetCreator
impl UnsafeUnpin for SetCreator
impl UnwindSafe for SetCreator