pub struct SetVirtualQuoteReserves {
pub global: Pubkey,
pub authority: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for SetVirtualQuoteReserves.
Fields
global: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for SetVirtualQuoteReserveswhere
Pubkey: BorshSerialize,
impl BorshSerialize for SetVirtualQuoteReserveswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for SetVirtualQuoteReserves
impl ToAccountMetas for SetVirtualQuoteReserves
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for SetVirtualQuoteReserves
impl RefUnwindSafe for SetVirtualQuoteReserves
impl Send for SetVirtualQuoteReserves
impl Sync for SetVirtualQuoteReserves
impl Unpin for SetVirtualQuoteReserves
impl UnsafeUnpin for SetVirtualQuoteReserves
impl UnwindSafe for SetVirtualQuoteReserves