pub struct UpdateBuybackConfig {
pub global: Pubkey,
pub authority: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for UpdateBuybackConfig.
Fields
global: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateBuybackConfigwhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateBuybackConfigwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateBuybackConfig
impl ToAccountMetas for UpdateBuybackConfig
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateBuybackConfig
impl RefUnwindSafe for UpdateBuybackConfig
impl Send for UpdateBuybackConfig
impl Sync for UpdateBuybackConfig
impl Unpin for UpdateBuybackConfig
impl UnsafeUnpin for UpdateBuybackConfig
impl UnwindSafe for UpdateBuybackConfig