pub struct AddQuoteMint {
pub quote_mint: Pubkey,
}Expand description
Instruction argument
Fields
quote_mint: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for AddQuoteMintwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for AddQuoteMintwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AddQuoteMintwhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddQuoteMintwhere
Pubkey: BorshSerialize,
Sourceimpl Discriminator for AddQuoteMint
impl Discriminator for AddQuoteMint
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for AddQuoteMint
impl InstructionData for AddQuoteMint