pub struct Create {
pub name: String,
pub symbol: String,
pub uri: String,
pub creator: Pubkey,
}Expand description
Instruction argument
Fields
name: Stringsymbol: Stringuri: Stringcreator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for Create
impl BorshDeserialize for Create
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Create
impl BorshSerialize for Create
Sourceimpl Discriminator for Create
impl Discriminator for Create
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for Create
impl InstructionData for Create