pub struct CreateV2 {
pub name: String,
pub symbol: String,
pub uri: String,
pub creator: Pubkey,
pub is_mayhem_mode: bool,
pub is_cashback_enabled: OptionBool,
}Expand description
Instruction argument
Fields
name: Stringsymbol: Stringuri: Stringcreator: Pubkeyis_mayhem_mode: boolis_cashback_enabled: OptionBoolTrait Implementations
Sourceimpl BorshDeserialize for CreateV2
impl BorshDeserialize for CreateV2
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateV2where
String: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
OptionBool: BorshSerialize,
impl BorshSerialize for CreateV2where
String: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
OptionBool: BorshSerialize,
Sourceimpl Discriminator for CreateV2
impl Discriminator for CreateV2
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CreateV2
impl InstructionData for CreateV2