pub struct SellV2 {
pub amount: u64,
pub min_sol_output: u64,
}Expand description
Instruction argument
Fields
amount: u64min_sol_output: u64Trait Implementations
Sourceimpl BorshDeserialize for SellV2where
u64: BorshDeserialize,
impl BorshDeserialize for SellV2where
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SellV2where
u64: BorshSerialize,
impl BorshSerialize for SellV2where
u64: BorshSerialize,
Sourceimpl Discriminator for SellV2
impl Discriminator for SellV2
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for SellV2
impl InstructionData for SellV2