pub struct ClaimCashbackEvent {
pub user: Pubkey,
pub amount: u64,
pub timestamp: i64,
pub total_claimed: u64,
pub total_cashback_earned: u64,
}Fields
user: Pubkeyamount: u64timestamp: i64total_claimed: u64total_cashback_earned: u64Trait Implementations
Sourceimpl BorshDeserialize for ClaimCashbackEvent
impl BorshDeserialize for ClaimCashbackEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ClaimCashbackEvent
impl BorshSerialize for ClaimCashbackEvent
Sourceimpl Clone for ClaimCashbackEvent
impl Clone for ClaimCashbackEvent
Sourcefn clone(&self) -> ClaimCashbackEvent
fn clone(&self) -> ClaimCashbackEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClaimCashbackEvent
impl Debug for ClaimCashbackEvent
Sourceimpl Default for ClaimCashbackEvent
impl Default for ClaimCashbackEvent
Sourcefn default() -> ClaimCashbackEvent
fn default() -> ClaimCashbackEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for ClaimCashbackEvent
impl Discriminator for ClaimCashbackEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for ClaimCashbackEvent