pub struct ClaimTokenIncentivesEvent {
pub user: Pubkey,
pub mint: Pubkey,
pub amount: u64,
pub timestamp: i64,
pub total_claimed_tokens: u64,
pub current_sol_volume: u64,
}Fields
user: Pubkeymint: Pubkeyamount: u64timestamp: i64total_claimed_tokens: u64current_sol_volume: u64Trait Implementations
Sourceimpl BorshDeserialize for ClaimTokenIncentivesEvent
impl BorshDeserialize for ClaimTokenIncentivesEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for ClaimTokenIncentivesEvent
impl Clone for ClaimTokenIncentivesEvent
Sourcefn clone(&self) -> ClaimTokenIncentivesEvent
fn clone(&self) -> ClaimTokenIncentivesEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClaimTokenIncentivesEvent
impl Debug for ClaimTokenIncentivesEvent
Sourceimpl Default for ClaimTokenIncentivesEvent
impl Default for ClaimTokenIncentivesEvent
Sourcefn default() -> ClaimTokenIncentivesEvent
fn default() -> ClaimTokenIncentivesEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for ClaimTokenIncentivesEvent
impl Discriminator for ClaimTokenIncentivesEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for ClaimTokenIncentivesEvent