pub struct CloseUserVolumeAccumulatorEvent {
pub user: Pubkey,
pub timestamp: i64,
pub total_unclaimed_tokens: u64,
pub total_claimed_tokens: u64,
pub current_sol_volume: u64,
pub last_update_timestamp: i64,
}Fields
user: Pubkeytimestamp: i64total_unclaimed_tokens: u64total_claimed_tokens: u64current_sol_volume: u64last_update_timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for CloseUserVolumeAccumulatorEvent
impl BorshDeserialize for CloseUserVolumeAccumulatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CloseUserVolumeAccumulatorEvent
impl Clone for CloseUserVolumeAccumulatorEvent
Sourcefn clone(&self) -> CloseUserVolumeAccumulatorEvent
fn clone(&self) -> CloseUserVolumeAccumulatorEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CloseUserVolumeAccumulatorEvent
impl Default for CloseUserVolumeAccumulatorEvent
Sourcefn default() -> CloseUserVolumeAccumulatorEvent
fn default() -> CloseUserVolumeAccumulatorEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for CloseUserVolumeAccumulatorEvent
impl Discriminator for CloseUserVolumeAccumulatorEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for CloseUserVolumeAccumulatorEvent