pub struct CollectCreatorFeeEvent {
pub timestamp: i64,
pub creator: Pubkey,
pub creator_fee: u64,
}Fields
timestamp: i64creator: Pubkeycreator_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for CollectCreatorFeeEvent
impl BorshDeserialize for CollectCreatorFeeEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CollectCreatorFeeEvent
impl Clone for CollectCreatorFeeEvent
Sourcefn clone(&self) -> CollectCreatorFeeEvent
fn clone(&self) -> CollectCreatorFeeEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollectCreatorFeeEvent
impl Debug for CollectCreatorFeeEvent
Sourceimpl Default for CollectCreatorFeeEvent
impl Default for CollectCreatorFeeEvent
Sourcefn default() -> CollectCreatorFeeEvent
fn default() -> CollectCreatorFeeEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for CollectCreatorFeeEvent
impl Discriminator for CollectCreatorFeeEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for CollectCreatorFeeEvent