pub struct CreateEvent {Show 17 fields
pub name: String,
pub symbol: String,
pub uri: String,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub user: Pubkey,
pub creator: Pubkey,
pub timestamp: i64,
pub virtual_token_reserves: u64,
pub virtual_sol_reserves: u64,
pub real_token_reserves: u64,
pub token_total_supply: u64,
pub token_program: Pubkey,
pub is_mayhem_mode: bool,
pub is_cashback_enabled: bool,
pub quote_mint: Pubkey,
pub virtual_quote_reserves: u64,
}Fields
name: Stringsymbol: Stringuri: Stringmint: Pubkeybonding_curve: Pubkeyuser: Pubkeycreator: Pubkeytimestamp: i64virtual_token_reserves: u64virtual_sol_reserves: u64real_token_reserves: u64token_total_supply: u64token_program: Pubkeyis_mayhem_mode: boolis_cashback_enabled: boolquote_mint: Pubkeyvirtual_quote_reserves: u64Trait Implementations
Sourceimpl BorshDeserialize for CreateEvent
impl BorshDeserialize for CreateEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateEventwhere
String: BorshSerialize,
Pubkey: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
impl BorshSerialize for CreateEventwhere
String: BorshSerialize,
Pubkey: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
Sourceimpl Clone for CreateEvent
impl Clone for CreateEvent
Sourcefn clone(&self) -> CreateEvent
fn clone(&self) -> CreateEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateEvent
impl Debug for CreateEvent
Sourceimpl Default for CreateEvent
impl Default for CreateEvent
Sourcefn default() -> CreateEvent
fn default() -> CreateEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for CreateEvent
impl Discriminator for CreateEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more