pub struct DistributeCreatorFeesEvent {
pub timestamp: i64,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub sharing_config: Pubkey,
pub admin: Pubkey,
pub shareholders: Vec<Shareholder>,
pub distributed: u64,
}Fields
timestamp: i64mint: Pubkeybonding_curve: Pubkeysharing_config: Pubkeyadmin: Pubkeydistributed: u64Trait Implementations
Sourceimpl BorshDeserialize for DistributeCreatorFeesEventwhere
i64: BorshDeserialize,
Pubkey: BorshDeserialize,
Vec<Shareholder>: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for DistributeCreatorFeesEventwhere
i64: BorshDeserialize,
Pubkey: BorshDeserialize,
Vec<Shareholder>: BorshDeserialize,
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DistributeCreatorFeesEventwhere
i64: BorshSerialize,
Pubkey: BorshSerialize,
Vec<Shareholder>: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for DistributeCreatorFeesEventwhere
i64: BorshSerialize,
Pubkey: BorshSerialize,
Vec<Shareholder>: BorshSerialize,
u64: BorshSerialize,
Sourceimpl Clone for DistributeCreatorFeesEvent
impl Clone for DistributeCreatorFeesEvent
Sourcefn clone(&self) -> DistributeCreatorFeesEvent
fn clone(&self) -> DistributeCreatorFeesEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DistributeCreatorFeesEvent
impl Debug for DistributeCreatorFeesEvent
Sourceimpl Default for DistributeCreatorFeesEvent
impl Default for DistributeCreatorFeesEvent
Sourcefn default() -> DistributeCreatorFeesEvent
fn default() -> DistributeCreatorFeesEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for DistributeCreatorFeesEvent
impl Discriminator for DistributeCreatorFeesEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more