pub struct InitUserVolumeAccumulatorEvent {
pub payer: Pubkey,
pub user: Pubkey,
pub timestamp: i64,
}Fields
payer: Pubkeyuser: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for InitUserVolumeAccumulatorEvent
impl BorshDeserialize for InitUserVolumeAccumulatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for InitUserVolumeAccumulatorEvent
impl Clone for InitUserVolumeAccumulatorEvent
Sourcefn clone(&self) -> InitUserVolumeAccumulatorEvent
fn clone(&self) -> InitUserVolumeAccumulatorEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for InitUserVolumeAccumulatorEvent
impl Default for InitUserVolumeAccumulatorEvent
Sourcefn default() -> InitUserVolumeAccumulatorEvent
fn default() -> InitUserVolumeAccumulatorEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for InitUserVolumeAccumulatorEvent
impl Discriminator for InitUserVolumeAccumulatorEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for InitUserVolumeAccumulatorEvent