pub struct ReservedFeeRecipientsEvent {
pub timestamp: i64,
pub reserved_fee_recipient: Pubkey,
pub reserved_fee_recipients: [Pubkey; 7],
}Fields
timestamp: i64reserved_fee_recipient: Pubkeyreserved_fee_recipients: [Pubkey; 7]Trait Implementations
Sourceimpl BorshDeserialize for ReservedFeeRecipientsEvent
impl BorshDeserialize for ReservedFeeRecipientsEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for ReservedFeeRecipientsEvent
impl Clone for ReservedFeeRecipientsEvent
Sourcefn clone(&self) -> ReservedFeeRecipientsEvent
fn clone(&self) -> ReservedFeeRecipientsEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReservedFeeRecipientsEvent
impl Debug for ReservedFeeRecipientsEvent
Sourceimpl Default for ReservedFeeRecipientsEvent
impl Default for ReservedFeeRecipientsEvent
Sourcefn default() -> ReservedFeeRecipientsEvent
fn default() -> ReservedFeeRecipientsEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for ReservedFeeRecipientsEvent
impl Discriminator for ReservedFeeRecipientsEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for ReservedFeeRecipientsEvent