pub struct SetCreatorEvent {
pub timestamp: i64,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub creator: Pubkey,
}Fields
timestamp: i64mint: Pubkeybonding_curve: Pubkeycreator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for SetCreatorEvent
impl BorshDeserialize for SetCreatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetCreatorEvent
impl BorshSerialize for SetCreatorEvent
Sourceimpl Clone for SetCreatorEvent
impl Clone for SetCreatorEvent
Sourcefn clone(&self) -> SetCreatorEvent
fn clone(&self) -> SetCreatorEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetCreatorEvent
impl Debug for SetCreatorEvent
Sourceimpl Default for SetCreatorEvent
impl Default for SetCreatorEvent
Sourcefn default() -> SetCreatorEvent
fn default() -> SetCreatorEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for SetCreatorEvent
impl Discriminator for SetCreatorEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for SetCreatorEvent