pub struct SetMetaplexCreatorEvent {
pub timestamp: i64,
pub mint: Pubkey,
pub bonding_curve: Pubkey,
pub metadata: Pubkey,
pub creator: Pubkey,
}Fields
timestamp: i64mint: Pubkeybonding_curve: Pubkeymetadata: Pubkeycreator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for SetMetaplexCreatorEvent
impl BorshDeserialize for SetMetaplexCreatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SetMetaplexCreatorEvent
impl Clone for SetMetaplexCreatorEvent
Sourcefn clone(&self) -> SetMetaplexCreatorEvent
fn clone(&self) -> SetMetaplexCreatorEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetMetaplexCreatorEvent
impl Debug for SetMetaplexCreatorEvent
Sourceimpl Default for SetMetaplexCreatorEvent
impl Default for SetMetaplexCreatorEvent
Sourcefn default() -> SetMetaplexCreatorEvent
fn default() -> SetMetaplexCreatorEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for SetMetaplexCreatorEvent
impl Discriminator for SetMetaplexCreatorEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for SetMetaplexCreatorEvent