pub struct SetParamsEvent {Show 14 fields
pub initial_virtual_token_reserves: u64,
pub initial_virtual_sol_reserves: u64,
pub initial_real_token_reserves: u64,
pub final_real_sol_reserves: u64,
pub token_total_supply: u64,
pub fee_basis_points: u64,
pub withdraw_authority: Pubkey,
pub enable_migrate: bool,
pub pool_migration_fee: u64,
pub creator_fee_basis_points: u64,
pub fee_recipients: [Pubkey; 8],
pub timestamp: i64,
pub set_creator_authority: Pubkey,
pub admin_set_creator_authority: Pubkey,
}Fields
initial_virtual_token_reserves: u64initial_virtual_sol_reserves: u64initial_real_token_reserves: u64final_real_sol_reserves: u64token_total_supply: u64fee_basis_points: u64enable_migrate: boolpool_migration_fee: u64creator_fee_basis_points: u64fee_recipients: [Pubkey; 8]timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for SetParamsEventwhere
u64: BorshDeserialize,
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
[Pubkey; 8]: BorshDeserialize,
i64: BorshDeserialize,
impl BorshDeserialize for SetParamsEventwhere
u64: BorshDeserialize,
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
[Pubkey; 8]: BorshDeserialize,
i64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for SetParamsEventwhere
u64: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
[Pubkey; 8]: BorshSerialize,
i64: BorshSerialize,
impl BorshSerialize for SetParamsEventwhere
u64: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
[Pubkey; 8]: BorshSerialize,
i64: BorshSerialize,
Sourceimpl Clone for SetParamsEvent
impl Clone for SetParamsEvent
Sourcefn clone(&self) -> SetParamsEvent
fn clone(&self) -> SetParamsEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetParamsEvent
impl Debug for SetParamsEvent
Sourceimpl Default for SetParamsEvent
impl Default for SetParamsEvent
Sourcefn default() -> SetParamsEvent
fn default() -> SetParamsEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for SetParamsEvent
impl Discriminator for SetParamsEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for SetParamsEvent