pub struct SyncUserVolumeAccumulatorEvent {
pub user: Pubkey,
pub total_claimed_tokens_before: u64,
pub total_claimed_tokens_after: u64,
pub timestamp: i64,
}Fields
user: Pubkeytotal_claimed_tokens_before: u64total_claimed_tokens_after: u64timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for SyncUserVolumeAccumulatorEvent
impl BorshDeserialize for SyncUserVolumeAccumulatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SyncUserVolumeAccumulatorEvent
impl Clone for SyncUserVolumeAccumulatorEvent
Sourcefn clone(&self) -> SyncUserVolumeAccumulatorEvent
fn clone(&self) -> SyncUserVolumeAccumulatorEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for SyncUserVolumeAccumulatorEvent
impl Default for SyncUserVolumeAccumulatorEvent
Sourcefn default() -> SyncUserVolumeAccumulatorEvent
fn default() -> SyncUserVolumeAccumulatorEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for SyncUserVolumeAccumulatorEvent
impl Discriminator for SyncUserVolumeAccumulatorEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for SyncUserVolumeAccumulatorEvent