pub struct TradeEvent {Show 31 fields
pub mint: Pubkey,
pub sol_amount: u64,
pub token_amount: u64,
pub is_buy: bool,
pub user: Pubkey,
pub timestamp: i64,
pub virtual_sol_reserves: u64,
pub virtual_token_reserves: u64,
pub real_sol_reserves: u64,
pub real_token_reserves: u64,
pub fee_recipient: Pubkey,
pub fee_basis_points: u64,
pub fee: u64,
pub creator: Pubkey,
pub creator_fee_basis_points: u64,
pub creator_fee: u64,
pub track_volume: bool,
pub total_unclaimed_tokens: u64,
pub total_claimed_tokens: u64,
pub current_sol_volume: u64,
pub last_update_timestamp: i64,
pub ix_name: String,
pub mayhem_mode: bool,
pub cashback_fee_basis_points: u64,
pub cashback: u64,
pub buyback_fee_basis_points: u64,
pub buyback_fee: u64,
pub shareholders: Vec<Shareholder>,
pub quote_amount: u64,
pub virtual_quote_reserves: u64,
pub real_quote_reserves: u64,
}Expand description
ix_name: “buy” | “sell” | “buy_exact_sol_in”
Fields
mint: Pubkeysol_amount: u64token_amount: u64is_buy: booluser: Pubkeytimestamp: i64virtual_sol_reserves: u64virtual_token_reserves: u64real_sol_reserves: u64real_token_reserves: u64fee_recipient: Pubkeyfee_basis_points: u64fee: u64creator: Pubkeycreator_fee_basis_points: u64creator_fee: u64track_volume: booltotal_unclaimed_tokens: u64total_claimed_tokens: u64current_sol_volume: u64last_update_timestamp: i64ix_name: Stringmayhem_mode: boolcashback_fee_basis_points: u64cashback: u64buyback_fee_basis_points: u64buyback_fee: u64quote_amount: u64virtual_quote_reserves: u64real_quote_reserves: u64Trait Implementations
Sourceimpl BorshDeserialize for TradeEvent
impl BorshDeserialize for TradeEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TradeEventwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
i64: BorshSerialize,
String: BorshSerialize,
Vec<Shareholder>: BorshSerialize,
impl BorshSerialize for TradeEventwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
i64: BorshSerialize,
String: BorshSerialize,
Vec<Shareholder>: BorshSerialize,
Sourceimpl Clone for TradeEvent
impl Clone for TradeEvent
Sourcefn clone(&self) -> TradeEvent
fn clone(&self) -> TradeEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TradeEvent
impl Debug for TradeEvent
Sourceimpl Default for TradeEvent
impl Default for TradeEvent
Sourcefn default() -> TradeEvent
fn default() -> TradeEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for TradeEvent
impl Discriminator for TradeEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more