pub struct CreateV2 {Show 16 fields
pub mint: Pubkey,
pub mint_authority: Pubkey,
pub bonding_curve: Pubkey,
pub associated_bonding_curve: Pubkey,
pub global: Pubkey,
pub user: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
pub mayhem_program_id: Pubkey,
pub global_params: Pubkey,
pub sol_vault: Pubkey,
pub mayhem_state: Pubkey,
pub mayhem_token_vault: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for CreateV2.
Fields
mint: Pubkeybonding_curve: Pubkeyassociated_bonding_curve: Pubkeyglobal: Pubkeyuser: Pubkeysystem_program: Pubkeytoken_program: Pubkeyassociated_token_program: Pubkeymayhem_program_id: Pubkeyglobal_params: Pubkeysol_vault: Pubkeymayhem_state: Pubkeymayhem_token_vault: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateV2where
Pubkey: BorshSerialize,
impl BorshSerialize for CreateV2where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateV2
impl ToAccountMetas for CreateV2
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateV2
impl RefUnwindSafe for CreateV2
impl Send for CreateV2
impl Sync for CreateV2
impl Unpin for CreateV2
impl UnsafeUnpin for CreateV2
impl UnwindSafe for CreateV2