pub struct AdminUpdateTokenIncentives {
pub start_time: i64,
pub end_time: i64,
pub seconds_in_a_day: i64,
pub day_number: u64,
pub pump_token_supply_per_day: u64,
}Expand description
Instruction argument
Fields
start_time: i64end_time: i64seconds_in_a_day: i64day_number: u64pump_token_supply_per_day: u64Trait Implementations
Sourceimpl BorshDeserialize for AdminUpdateTokenIncentives
impl BorshDeserialize for AdminUpdateTokenIncentives
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for AdminUpdateTokenIncentives
impl Discriminator for AdminUpdateTokenIncentives
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more