pub struct BuyExactSolIn {
pub spendable_sol_in: u64,
pub min_tokens_out: u64,
pub track_volume: OptionBool,
}Expand description
Instruction argument
Fields
spendable_sol_in: u64min_tokens_out: u64track_volume: OptionBoolTrait Implementations
Sourceimpl BorshDeserialize for BuyExactSolIn
impl BorshDeserialize for BuyExactSolIn
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BuyExactSolIn
impl BorshSerialize for BuyExactSolIn
Sourceimpl Discriminator for BuyExactSolIn
impl Discriminator for BuyExactSolIn
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for BuyExactSolIn
impl InstructionData for BuyExactSolIn