pub struct DistributeCreatorFeesV2 {
pub initialize_ata: bool,
}Expand description
Instruction argument
Fields
initialize_ata: boolTrait Implementations
Sourceimpl BorshDeserialize for DistributeCreatorFeesV2where
bool: BorshDeserialize,
impl BorshDeserialize for DistributeCreatorFeesV2where
bool: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DistributeCreatorFeesV2where
bool: BorshSerialize,
impl BorshSerialize for DistributeCreatorFeesV2where
bool: BorshSerialize,
Sourceimpl Discriminator for DistributeCreatorFeesV2
impl Discriminator for DistributeCreatorFeesV2
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more