pub struct CompletePumpAmmMigrationEvent {
pub user: Pubkey,
pub mint: Pubkey,
pub mint_amount: u64,
pub sol_amount: u64,
pub pool_migration_fee: u64,
pub bonding_curve: Pubkey,
pub timestamp: i64,
pub pool: Pubkey,
}Fields
user: Pubkeymint: Pubkeymint_amount: u64sol_amount: u64pool_migration_fee: u64bonding_curve: Pubkeytimestamp: i64pool: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for CompletePumpAmmMigrationEvent
impl BorshDeserialize for CompletePumpAmmMigrationEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CompletePumpAmmMigrationEvent
impl Clone for CompletePumpAmmMigrationEvent
Sourcefn clone(&self) -> CompletePumpAmmMigrationEvent
fn clone(&self) -> CompletePumpAmmMigrationEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CompletePumpAmmMigrationEvent
impl Default for CompletePumpAmmMigrationEvent
Sourcefn default() -> CompletePumpAmmMigrationEvent
fn default() -> CompletePumpAmmMigrationEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for CompletePumpAmmMigrationEvent
impl Discriminator for CompletePumpAmmMigrationEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for CompletePumpAmmMigrationEvent