pub struct MinimumDistributableFeeEvent {
pub minimum_required: u64,
pub distributable_fees: u64,
pub can_distribute: bool,
}Fields
minimum_required: u64distributable_fees: u64can_distribute: boolTrait Implementations
Sourceimpl BorshDeserialize for MinimumDistributableFeeEvent
impl BorshDeserialize for MinimumDistributableFeeEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MinimumDistributableFeeEvent
impl Clone for MinimumDistributableFeeEvent
Sourcefn clone(&self) -> MinimumDistributableFeeEvent
fn clone(&self) -> MinimumDistributableFeeEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MinimumDistributableFeeEvent
impl Debug for MinimumDistributableFeeEvent
Sourceimpl Default for MinimumDistributableFeeEvent
impl Default for MinimumDistributableFeeEvent
Sourcefn default() -> MinimumDistributableFeeEvent
fn default() -> MinimumDistributableFeeEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for MinimumDistributableFeeEvent
impl Discriminator for MinimumDistributableFeeEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for MinimumDistributableFeeEvent