pub struct UpdateGlobalAuthorityEvent {
pub global: Pubkey,
pub authority: Pubkey,
pub new_authority: Pubkey,
pub timestamp: i64,
}Fields
global: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for UpdateGlobalAuthorityEvent
impl BorshDeserialize for UpdateGlobalAuthorityEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateGlobalAuthorityEvent
impl Clone for UpdateGlobalAuthorityEvent
Sourcefn clone(&self) -> UpdateGlobalAuthorityEvent
fn clone(&self) -> UpdateGlobalAuthorityEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateGlobalAuthorityEvent
impl Debug for UpdateGlobalAuthorityEvent
Sourceimpl Default for UpdateGlobalAuthorityEvent
impl Default for UpdateGlobalAuthorityEvent
Sourcefn default() -> UpdateGlobalAuthorityEvent
fn default() -> UpdateGlobalAuthorityEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for UpdateGlobalAuthorityEvent
impl Discriminator for UpdateGlobalAuthorityEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for UpdateGlobalAuthorityEvent