pub struct UpdateMayhemVirtualParamsEvent {
pub timestamp: i64,
pub mint: Pubkey,
pub virtual_token_reserves: u64,
pub virtual_sol_reserves: u64,
pub new_virtual_token_reserves: u64,
pub new_virtual_sol_reserves: u64,
pub real_token_reserves: u64,
pub real_sol_reserves: u64,
}Fields
timestamp: i64mint: Pubkeyvirtual_token_reserves: u64virtual_sol_reserves: u64new_virtual_token_reserves: u64new_virtual_sol_reserves: u64real_token_reserves: u64real_sol_reserves: u64Trait Implementations
Sourceimpl BorshDeserialize for UpdateMayhemVirtualParamsEvent
impl BorshDeserialize for UpdateMayhemVirtualParamsEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UpdateMayhemVirtualParamsEvent
impl Clone for UpdateMayhemVirtualParamsEvent
Sourcefn clone(&self) -> UpdateMayhemVirtualParamsEvent
fn clone(&self) -> UpdateMayhemVirtualParamsEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateMayhemVirtualParamsEvent
impl Default for UpdateMayhemVirtualParamsEvent
Sourcefn default() -> UpdateMayhemVirtualParamsEvent
fn default() -> UpdateMayhemVirtualParamsEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for UpdateMayhemVirtualParamsEvent
impl Discriminator for UpdateMayhemVirtualParamsEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for UpdateMayhemVirtualParamsEvent