pub struct FeeTier {
pub market_cap_lamports_threshold: u128,
pub fees: Fees,
}Fields
market_cap_lamports_threshold: u128fees: FeesTrait Implementations
Sourceimpl BorshDeserialize for FeeTier
impl BorshDeserialize for FeeTier
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for FeeTier
impl BorshSerialize for FeeTier
impl Copy for FeeTier