pub struct OptionBool(pub bool);Tuple Fields
0: boolTrait Implementations
Sourceimpl BorshDeserialize for OptionBool
impl BorshDeserialize for OptionBool
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OptionBool
impl BorshSerialize for OptionBool
Sourceimpl Clone for OptionBool
impl Clone for OptionBool
Sourcefn clone(&self) -> OptionBool
fn clone(&self) -> OptionBool
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OptionBool
impl Debug for OptionBool
Sourceimpl Default for OptionBool
impl Default for OptionBool
Sourcefn default() -> OptionBool
fn default() -> OptionBool
Returns the “default value” for a type. Read more
impl Copy for OptionBool