pub struct AgentBuybackTrigger {
pub swap_instruction_data: Vec<u8>,
}Expand description
Instruction argument
Fields
swap_instruction_data: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for AgentBuybackTrigger
impl BorshDeserialize for AgentBuybackTrigger
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AgentBuybackTrigger
impl BorshSerialize for AgentBuybackTrigger
Sourceimpl Discriminator for AgentBuybackTrigger
impl Discriminator for AgentBuybackTrigger
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more