pub struct AgentInitialize {
pub authority: Pubkey,
pub buyback_bps: u16,
}Expand description
Instruction argument
Fields
buyback_bps: u16Trait Implementations
Sourceimpl BorshDeserialize for AgentInitialize
impl BorshDeserialize for AgentInitialize
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AgentInitialize
impl BorshSerialize for AgentInitialize
Sourceimpl Discriminator for AgentInitialize
impl Discriminator for AgentInitialize
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for AgentInitialize
impl InstructionData for AgentInitialize