pub struct AgentWithdrawEvent {
pub tokenized_agent_mint: Pubkey,
pub currency_mint: Pubkey,
pub amount: u64,
pub receiver: Pubkey,
pub timestamp: i64,
}Fields
tokenized_agent_mint: Pubkeycurrency_mint: Pubkeyamount: u64receiver: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for AgentWithdrawEvent
impl BorshDeserialize for AgentWithdrawEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AgentWithdrawEvent
impl BorshSerialize for AgentWithdrawEvent
Sourceimpl Clone for AgentWithdrawEvent
impl Clone for AgentWithdrawEvent
Sourcefn clone(&self) -> AgentWithdrawEvent
fn clone(&self) -> AgentWithdrawEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentWithdrawEvent
impl Debug for AgentWithdrawEvent
Sourceimpl Default for AgentWithdrawEvent
impl Default for AgentWithdrawEvent
Sourcefn default() -> AgentWithdrawEvent
fn default() -> AgentWithdrawEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for AgentWithdrawEvent
impl Discriminator for AgentWithdrawEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for AgentWithdrawEvent