pub struct GlobalConfigInitializeEvent {
pub global_config: Pubkey,
pub protocol_authority: Pubkey,
pub buyback_authority: Pubkey,
pub timestamp: i64,
}Fields
global_config: Pubkeytimestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for GlobalConfigInitializeEvent
impl BorshDeserialize for GlobalConfigInitializeEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for GlobalConfigInitializeEvent
impl Clone for GlobalConfigInitializeEvent
Sourcefn clone(&self) -> GlobalConfigInitializeEvent
fn clone(&self) -> GlobalConfigInitializeEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GlobalConfigInitializeEvent
impl Debug for GlobalConfigInitializeEvent
Sourceimpl Default for GlobalConfigInitializeEvent
impl Default for GlobalConfigInitializeEvent
Sourcefn default() -> GlobalConfigInitializeEvent
fn default() -> GlobalConfigInitializeEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for GlobalConfigInitializeEvent
impl Discriminator for GlobalConfigInitializeEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for GlobalConfigInitializeEvent