pub struct UpdateBuybackConfig {
pub buyback_basis_points: Option<u64>,
}Expand description
Instruction argument
Fields
buyback_basis_points: Option<u64>Trait Implementations
Sourceimpl BorshDeserialize for UpdateBuybackConfig
impl BorshDeserialize for UpdateBuybackConfig
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateBuybackConfig
impl BorshSerialize for UpdateBuybackConfig
Sourceimpl Discriminator for UpdateBuybackConfig
impl Discriminator for UpdateBuybackConfig
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more