pub struct UpdateFeeConfig {
pub lp_fee_basis_points: u64,
pub protocol_fee_basis_points: u64,
pub protocol_fee_recipients: [Pubkey; 8],
pub coin_creator_fee_basis_points: u64,
pub admin_set_coin_creator_authority: Pubkey,
}Expand description
Instruction argument
Fields
lp_fee_basis_points: u64protocol_fee_basis_points: u64protocol_fee_recipients: [Pubkey; 8]coin_creator_fee_basis_points: u64Trait Implementations
Sourceimpl BorshDeserialize for UpdateFeeConfig
impl BorshDeserialize for UpdateFeeConfig
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateFeeConfig
impl BorshSerialize for UpdateFeeConfig
Sourceimpl Discriminator for UpdateFeeConfig
impl Discriminator for UpdateFeeConfig
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateFeeConfig
impl InstructionData for UpdateFeeConfig