pub struct AdminSetCoinCreatorEvent {
pub timestamp: i64,
pub admin_set_coin_creator_authority: Pubkey,
pub base_mint: Pubkey,
pub pool: Pubkey,
pub old_coin_creator: Pubkey,
pub new_coin_creator: Pubkey,
}Fields
timestamp: i64base_mint: Pubkeypool: Pubkeyold_coin_creator: Pubkeynew_coin_creator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for AdminSetCoinCreatorEvent
impl BorshDeserialize for AdminSetCoinCreatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AdminSetCoinCreatorEvent
impl Clone for AdminSetCoinCreatorEvent
Sourcefn clone(&self) -> AdminSetCoinCreatorEvent
fn clone(&self) -> AdminSetCoinCreatorEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdminSetCoinCreatorEvent
impl Debug for AdminSetCoinCreatorEvent
Sourceimpl Default for AdminSetCoinCreatorEvent
impl Default for AdminSetCoinCreatorEvent
Sourcefn default() -> AdminSetCoinCreatorEvent
fn default() -> AdminSetCoinCreatorEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for AdminSetCoinCreatorEvent
impl Discriminator for AdminSetCoinCreatorEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for AdminSetCoinCreatorEvent