pub struct AdminUpdateTokenIncentivesEvent {
pub start_time: i64,
pub end_time: i64,
pub day_number: u64,
pub token_supply_per_day: u64,
pub mint: Pubkey,
pub seconds_in_a_day: i64,
pub timestamp: i64,
}Fields
start_time: i64end_time: i64day_number: u64token_supply_per_day: u64mint: Pubkeyseconds_in_a_day: i64timestamp: i64Trait Implementations
Sourceimpl BorshDeserialize for AdminUpdateTokenIncentivesEvent
impl BorshDeserialize for AdminUpdateTokenIncentivesEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for AdminUpdateTokenIncentivesEvent
impl Clone for AdminUpdateTokenIncentivesEvent
Sourcefn clone(&self) -> AdminUpdateTokenIncentivesEvent
fn clone(&self) -> AdminUpdateTokenIncentivesEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for AdminUpdateTokenIncentivesEvent
impl Default for AdminUpdateTokenIncentivesEvent
Sourcefn default() -> AdminUpdateTokenIncentivesEvent
fn default() -> AdminUpdateTokenIncentivesEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for AdminUpdateTokenIncentivesEvent
impl Discriminator for AdminUpdateTokenIncentivesEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for AdminUpdateTokenIncentivesEvent