pub struct CreatePoolEvent {Show 21 fields
pub timestamp: i64,
pub index: u16,
pub creator: Pubkey,
pub base_mint: Pubkey,
pub quote_mint: Pubkey,
pub base_mint_decimals: u8,
pub quote_mint_decimals: u8,
pub base_amount_in: u64,
pub quote_amount_in: u64,
pub pool_base_amount: u64,
pub pool_quote_amount: u64,
pub minimum_liquidity: u64,
pub initial_liquidity: u64,
pub lp_token_amount_out: u64,
pub pool_bump: u8,
pub pool: Pubkey,
pub lp_mint: Pubkey,
pub user_base_token_account: Pubkey,
pub user_quote_token_account: Pubkey,
pub coin_creator: Pubkey,
pub is_mayhem_mode: bool,
}Fields
timestamp: i64index: u16creator: Pubkeybase_mint: Pubkeyquote_mint: Pubkeybase_mint_decimals: u8quote_mint_decimals: u8base_amount_in: u64quote_amount_in: u64pool_base_amount: u64pool_quote_amount: u64minimum_liquidity: u64initial_liquidity: u64lp_token_amount_out: u64pool_bump: u8pool: Pubkeylp_mint: Pubkeyuser_base_token_account: Pubkeyuser_quote_token_account: Pubkeycoin_creator: Pubkeyis_mayhem_mode: boolTrait Implementations
Sourceimpl BorshDeserialize for CreatePoolEvent
impl BorshDeserialize for CreatePoolEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreatePoolEventwhere
i64: BorshSerialize,
u16: BorshSerialize,
Pubkey: BorshSerialize,
u8: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
impl BorshSerialize for CreatePoolEventwhere
i64: BorshSerialize,
u16: BorshSerialize,
Pubkey: BorshSerialize,
u8: BorshSerialize,
u64: BorshSerialize,
bool: BorshSerialize,
Sourceimpl Clone for CreatePoolEvent
impl Clone for CreatePoolEvent
Sourcefn clone(&self) -> CreatePoolEvent
fn clone(&self) -> CreatePoolEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatePoolEvent
impl Debug for CreatePoolEvent
Sourceimpl Default for CreatePoolEvent
impl Default for CreatePoolEvent
Sourcefn default() -> CreatePoolEvent
fn default() -> CreatePoolEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for CreatePoolEvent
impl Discriminator for CreatePoolEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for CreatePoolEvent