pub struct DisableEvent {
pub timestamp: i64,
pub admin: Pubkey,
pub disable_create_pool: bool,
pub disable_deposit: bool,
pub disable_withdraw: bool,
pub disable_buy: bool,
pub disable_sell: bool,
}Fields
timestamp: i64admin: Pubkeydisable_create_pool: booldisable_deposit: booldisable_withdraw: booldisable_buy: booldisable_sell: boolTrait Implementations
Sourceimpl BorshDeserialize for DisableEvent
impl BorshDeserialize for DisableEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DisableEvent
impl BorshSerialize for DisableEvent
Sourceimpl Clone for DisableEvent
impl Clone for DisableEvent
Sourcefn clone(&self) -> DisableEvent
fn clone(&self) -> DisableEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisableEvent
impl Debug for DisableEvent
Sourceimpl Default for DisableEvent
impl Default for DisableEvent
Sourcefn default() -> DisableEvent
fn default() -> DisableEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for DisableEvent
impl Discriminator for DisableEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for DisableEvent