pub struct ExtendAccountEvent {
pub timestamp: i64,
pub account: Pubkey,
pub user: Pubkey,
pub current_size: u64,
pub new_size: u64,
}Fields
timestamp: i64account: Pubkeyuser: Pubkeycurrent_size: u64new_size: u64Trait Implementations
Sourceimpl BorshDeserialize for ExtendAccountEvent
impl BorshDeserialize for ExtendAccountEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for ExtendAccountEvent
impl BorshSerialize for ExtendAccountEvent
Sourceimpl Clone for ExtendAccountEvent
impl Clone for ExtendAccountEvent
Sourcefn clone(&self) -> ExtendAccountEvent
fn clone(&self) -> ExtendAccountEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtendAccountEvent
impl Debug for ExtendAccountEvent
Sourceimpl Default for ExtendAccountEvent
impl Default for ExtendAccountEvent
Sourcefn default() -> ExtendAccountEvent
fn default() -> ExtendAccountEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for ExtendAccountEvent
impl Discriminator for ExtendAccountEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for ExtendAccountEvent