pub struct MigratePoolCoinCreatorEvent {
pub timestamp: i64,
pub base_mint: Pubkey,
pub pool: Pubkey,
pub sharing_config: Pubkey,
pub old_coin_creator: Pubkey,
pub new_coin_creator: Pubkey,
}Fields
timestamp: i64base_mint: Pubkeypool: Pubkeysharing_config: Pubkeyold_coin_creator: Pubkeynew_coin_creator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for MigratePoolCoinCreatorEvent
impl BorshDeserialize for MigratePoolCoinCreatorEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for MigratePoolCoinCreatorEvent
impl Clone for MigratePoolCoinCreatorEvent
Sourcefn clone(&self) -> MigratePoolCoinCreatorEvent
fn clone(&self) -> MigratePoolCoinCreatorEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MigratePoolCoinCreatorEvent
impl Debug for MigratePoolCoinCreatorEvent
Sourceimpl Default for MigratePoolCoinCreatorEvent
impl Default for MigratePoolCoinCreatorEvent
Sourcefn default() -> MigratePoolCoinCreatorEvent
fn default() -> MigratePoolCoinCreatorEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for MigratePoolCoinCreatorEvent
impl Discriminator for MigratePoolCoinCreatorEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for MigratePoolCoinCreatorEvent