pub struct UpdateAdminEvent {
pub timestamp: i64,
pub admin: Pubkey,
pub new_admin: Pubkey,
}Fields
timestamp: i64admin: Pubkeynew_admin: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for UpdateAdminEvent
impl BorshDeserialize for UpdateAdminEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateAdminEvent
impl BorshSerialize for UpdateAdminEvent
Sourceimpl Clone for UpdateAdminEvent
impl Clone for UpdateAdminEvent
Sourcefn clone(&self) -> UpdateAdminEvent
fn clone(&self) -> UpdateAdminEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateAdminEvent
impl Debug for UpdateAdminEvent
Sourceimpl Default for UpdateAdminEvent
impl Default for UpdateAdminEvent
Sourcefn default() -> UpdateAdminEvent
fn default() -> UpdateAdminEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for UpdateAdminEvent
impl Discriminator for UpdateAdminEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for UpdateAdminEvent