pub struct UpdateFeeConfigEvent {
pub timestamp: i64,
pub admin: Pubkey,
pub lp_fee_basis_points: u64,
pub protocol_fee_basis_points: u64,
pub protocol_fee_recipients: [Pubkey; 8],
pub coin_creator_fee_basis_points: u64,
pub admin_set_coin_creator_authority: Pubkey,
}Fields
timestamp: i64admin: Pubkeylp_fee_basis_points: u64protocol_fee_basis_points: u64protocol_fee_recipients: [Pubkey; 8]coin_creator_fee_basis_points: u64Trait Implementations
Sourceimpl BorshDeserialize for UpdateFeeConfigEventwhere
i64: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
[Pubkey; 8]: BorshDeserialize,
impl BorshDeserialize for UpdateFeeConfigEventwhere
i64: BorshDeserialize,
Pubkey: BorshDeserialize,
u64: BorshDeserialize,
[Pubkey; 8]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateFeeConfigEventwhere
i64: BorshSerialize,
Pubkey: BorshSerialize,
u64: BorshSerialize,
[Pubkey; 8]: BorshSerialize,
impl BorshSerialize for UpdateFeeConfigEventwhere
i64: BorshSerialize,
Pubkey: BorshSerialize,
u64: BorshSerialize,
[Pubkey; 8]: BorshSerialize,
Sourceimpl Clone for UpdateFeeConfigEvent
impl Clone for UpdateFeeConfigEvent
Sourcefn clone(&self) -> UpdateFeeConfigEvent
fn clone(&self) -> UpdateFeeConfigEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateFeeConfigEvent
impl Debug for UpdateFeeConfigEvent
Sourceimpl Default for UpdateFeeConfigEvent
impl Default for UpdateFeeConfigEvent
Sourcefn default() -> UpdateFeeConfigEvent
fn default() -> UpdateFeeConfigEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for UpdateFeeConfigEvent
impl Discriminator for UpdateFeeConfigEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for UpdateFeeConfigEvent