pub struct WithdrawEvent {Show 16 fields
pub timestamp: i64,
pub lp_token_amount_in: u64,
pub min_base_amount_out: u64,
pub min_quote_amount_out: u64,
pub user_base_token_reserves: u64,
pub user_quote_token_reserves: u64,
pub pool_base_token_reserves: u64,
pub pool_quote_token_reserves: u64,
pub base_amount_out: u64,
pub quote_amount_out: u64,
pub lp_mint_supply: u64,
pub pool: Pubkey,
pub user: Pubkey,
pub user_base_token_account: Pubkey,
pub user_quote_token_account: Pubkey,
pub user_pool_token_account: Pubkey,
}Fields
timestamp: i64lp_token_amount_in: u64min_base_amount_out: u64min_quote_amount_out: u64user_base_token_reserves: u64user_quote_token_reserves: u64pool_base_token_reserves: u64pool_quote_token_reserves: u64base_amount_out: u64quote_amount_out: u64lp_mint_supply: u64pool: Pubkeyuser: Pubkeyuser_base_token_account: Pubkeyuser_quote_token_account: Pubkeyuser_pool_token_account: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for WithdrawEvent
impl BorshDeserialize for WithdrawEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for WithdrawEvent
impl BorshSerialize for WithdrawEvent
Sourceimpl Clone for WithdrawEvent
impl Clone for WithdrawEvent
Sourcefn clone(&self) -> WithdrawEvent
fn clone(&self) -> WithdrawEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WithdrawEvent
impl Debug for WithdrawEvent
Sourceimpl Default for WithdrawEvent
impl Default for WithdrawEvent
Sourcefn default() -> WithdrawEvent
fn default() -> WithdrawEvent
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for WithdrawEvent
impl Discriminator for WithdrawEvent
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
impl Copy for WithdrawEvent